@@ -3,6 +3,7 @@ from datamonk.utils import functions as utils
 from datamonk.scriptorium.process import monitoring
 import datamonk.scriptorium.apps.dataform as dataform
 import os
+import json
 
 @prefect.task
 def dataform_transform(project_id=os.environ.get("DATAFORM_PROJECT_ID"),
@@ -16,7 +17,7 @@ def dataform_transform(project_id=os.environ.get("DATAFORM_PROJECT_ID"),
 
 @prefect.task
 def data_monitoring(config):
-    return utils.monitoring.run(rules_list=json.loads(config)["rules"])
+    return monitoring.run(rules_list=json.loads(config)["rules"])
 
 def prefect_parameter_read_json(path,param_name):
         return prefect.Parameter(param_name,
